==> openshift-model-5.1.0-sources.jar: io/fabric8/openshift/api/model/ProjectBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ProjectBuilder extends ProjectFluentImpl<ProjectBuilder> implements VisitableBuilder<Project,ProjectBuilder> {

    ProjectFluent<?> fluent;
    Boolean validationEnabled;

    public ProjectBuilder() {
        this(true);
    }

    public ProjectBuilder(Boolean validationEnabled) {
        this(new Project(), validationEnabled);
    }

    public ProjectBuilder(ProjectFluent<?> fluent) {
        this(fluent, true);
    }

    public ProjectBuilder(ProjectFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new Project(), validationEnabled);
    }

    public ProjectBuilder(ProjectFluent<?> fluent,Project instance) {
        this(fluent, instance, true);
    }

    public ProjectBuilder(ProjectFluent<?> fluent,Project instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        fluent.withSpec(instance.getSpec()); 
        fluent.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public ProjectBuilder(Project instance) {
        this(instance,true);
    }

    public ProjectBuilder(Project instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public Project build() {
        Project buildable = new Project(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        ProjectBuilder that = (ProjectBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> openshift-model-5.3.2-sources.jar: io/fabric8/openshift/api/model/ProjectBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ProjectBuilder extends ProjectFluentImpl<ProjectBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<Project,ProjectBuilder> {

    ProjectFluent<?> fluent;
    Boolean validationEnabled;

    public ProjectBuilder() {
        this(true);
    }

    public ProjectBuilder(Boolean validationEnabled) {
        this(new Project(), validationEnabled);
    }

    public ProjectBuilder(ProjectFluent<?> fluent) {
        this(fluent, true);
    }

    public ProjectBuilder(ProjectFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new Project(), validationEnabled);
    }

    public ProjectBuilder(ProjectFluent<?> fluent,Project instance) {
        this(fluent, instance, true);
    }

    public ProjectBuilder(ProjectFluent<?> fluent,Project instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        fluent.withSpec(instance.getSpec()); 
        fluent.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public ProjectBuilder(Project instance) {
        this(instance,true);
    }

    public ProjectBuilder(Project instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public Project build() {
        Project buildable = new Project(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        ProjectBuilder that = (ProjectBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
